@@ -1,4 +1,4 @@
-# $Id: RSA.pm,v 1.9 2001/03/05 22:54:25 btrott Exp $
+# $Id: RSA.pm,v 1.10 2001/03/12 19:40:31 btrott Exp $
 
 package Net::SSH::Perl::Auth::RSA;
 
@@ -11,7 +11,7 @@ use Net::SSH::Perl::Constants qw(
     SSH_SMSG_AUTH_RSA_CHALLENGE
     SSH_CMSG_AUTH_RSA_RESPONSE );
 
-use Net::SSH::Perl::Util qw( :rsa _load_public_key _load_private_key _read_passphrase );
+use Net::SSH::Perl::Util qw( :rsa :authfile _read_passphrase );
 use Net::SSH::Perl::Packet;
 use Net::SSH::Perl::Auth;
 use base qw( Net::SSH::Perl::Auth );
